@@ -4,6 +4,7 @@ from collections import namedtuple
 
 import pytest  # noqa: F401
 from lxml import etree
+from null_object import Null
 
 from broadworks_ocip import BroadworksAPI
 
@@ -418,4 +419,121 @@ def test_group_department_add_xml():
     )
 
 
+def test_nested_elements():
+    cmd = api.get_command_object(
+        "UserModifyRequest22",
+        user_id="user@example.com",
+        phone_number="123456789",
+        extension="1219",
+        sip_alias_list=Null,
+        endpoint=dict(
+            trunk_addressing=api.get_type_object(
+                "TrunkAddressingMultipleContactModify",
+                trunk_group_device_endpoint=Null,
+                enterprise_trunk_name="ET02",
+                alternate_trunk_identity=Null,
+                physical_location=Null,
+            ),
+        ),
+    )
+    check_command_xml(
+        (
+            b'<?xml version="1.0" encoding="ISO-8859-1"?>'
+            b'<BroadsoftDocument protocol="OCI" xmlns="C" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">'
+            b'<sessionId xmlns="">00000000-1111-2222-3333-444444444444</sessionId>'
+            b'<command xsi:type="UserModifyRequest22" xmlns="">'
+            b"<userId>user@example.com</userId>"
+            b"<phoneNumber>123456789</phoneNumber>"
+            b"<extension>1219</extension>"
+            b'<sipAliasList xsi:nil="true"/>'
+            b"<endpoint>"
+            b"<trunkAddressing>"
+            b'<trunkGroupDeviceEndpoint xsi:nil="true"/>'
+            b"<enterpriseTrunkName>ET02</enterpriseTrunkName>"
+            b'<alternateTrunkIdentity xsi:nil="true"/>'
+            b'<physicalLocation xsi:nil="true"/>'
+            b"</trunkAddressing>"
+            b"</endpoint>"
+            b"</command>"
+            b"</BroadsoftDocument>"
+        ),
+        cmd,
+    )
+
+
+def test_nested_elements2():
+    cmd = api.get_command_object(
+        "UserModifyRequest22",
+        user_id="user@example.com",
+        phone_number="123456789",
+        extension="1219",
+        sip_alias_list=api.get_type_object("ReplacementSIPAliasList", sip_alias=[]),
+        endpoint=dict(
+            trunk_addressing=api.get_type_object(
+                "TrunkAddressingMultipleContactModify",
+                trunk_group_device_endpoint=Null,
+                enterprise_trunk_name="ET02",
+                alternate_trunk_identity=Null,
+            ),
+        ),
+    )
+    check_command_xml(
+        (
+            b'<?xml version="1.0" encoding="ISO-8859-1"?>'
+            b'<BroadsoftDocument protocol="OCI" xmlns="C" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">'
+            b'<sessionId xmlns="">00000000-1111-2222-3333-444444444444</sessionId>'
+            b'<command xsi:type="UserModifyRequest22" xmlns="">'
+            b"<userId>user@example.com</userId>"
+            b"<phoneNumber>123456789</phoneNumber>"
+            b"<extension>1219</extension>"
+            b'<sipAliasList xsi:nil="true"/>'
+            b"<endpoint>"
+            b"<trunkAddressing>"
+            b'<trunkGroupDeviceEndpoint xsi:nil="true"/>'
+            b"<enterpriseTrunkName>ET02</enterpriseTrunkName>"
+            b'<alternateTrunkIdentity xsi:nil="true"/>'
+            b"</trunkAddressing>"
+            b"</endpoint>"
+            b"</command>"
+            b"</BroadsoftDocument>"
+        ),
+        cmd,
+    )
+
+
+def test_user_get_list_in_system():
+    cmd = api.get_command_object(
+        "UserGetListInSystemRequest",
+        response_size_limit=10,
+        search_criteria_dn=[
+            api.get_type_object(
+                "SearchCriteriaDn",
+                mode="Contains",
+                value="12345678",
+                is_case_insensitive=True,
+            ),
+        ],
+    )
+    assert cmd is not None
+    assert "UserGetListInSystemRequest" in str(type(cmd))
+
+    check_command_xml(
+        (
+            b'<?xml version="1.0" encoding="ISO-8859-1"?>'
+            b'<BroadsoftDocument protocol="OCI" xmlns="C" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">'
+            b'<sessionId xmlns="">00000000-1111-2222-3333-444444444444</sessionId>'
+            b'<command xsi:type="UserGetListInSystemRequest" xmlns="">'
+            b"<responseSizeLimit>10</responseSizeLimit>"
+            b"<searchCriteriaDn>"
+            b"<mode>Contains</mode>"
+            b"<value>12345678</value>"
+            b"<isCaseInsensitive>true</isCaseInsensitive>"
+            b"</searchCriteriaDn>"
+            b"</command>"
+            b"</BroadsoftDocument>"
+        ),
+        cmd,
+    )
+
+
 # end
